Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: content/child/service_worker/service_worker_network_provider.h

Issue 1221643014: Service Worker: Migrate to version_uuid and surface ServiceWorker.id. (Chromium 2/3) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/child/service_worker/service_worker_network_provider.h
diff --git a/content/child/service_worker/service_worker_network_provider.h b/content/child/service_worker/service_worker_network_provider.h
index 866edd6081d2537b27a48fff25c5e1f83ff4f039..56bf6738c894a850be8b976f021167b476cff586 100644
--- a/content/child/service_worker/service_worker_network_provider.h
+++ b/content/child/service_worker/service_worker_network_provider.h
@@ -44,9 +44,9 @@ class CONTENT_EXPORT ServiceWorkerNetworkProvider
ServiceWorkerProviderContext* context() { return context_.get(); }
// This method is called for a provider that's associated with a
// running service worker script. The version_id indicates which
// ServiceWorkerVersion should be used.
- void SetServiceWorkerVersionId(int64 version_id);
+ void SetServiceWorkerVersionId(std::string version_uuid);
private:
const int provider_id_;
@@ -44,9 +44,9 @@ class CONTENT_EXPORT ServiceWorkerNetworkProvider
ServiceWorkerProviderContext* context() { return context_.get(); }
// This method is called for a provider that's associated with a
- // running service worker script. The version_id indicates which
+ // running service worker script. The version_uuid indicates which
// ServiceWorkerVersion should be used.

Powered by Google App Engine
This is Rietveld 408576698